using System;
using System.Collections;
using Server.Targeting;
using Server.Network;
using Server.Mobiles;
using Server.Items;
using Server.Spells;

namespace Server.ACC.CSS.Systems.DarkElf
{
	public class DarkElfSpidersFangSpell : DarkElfSpell
	{
		private static SpellInfo m_Info = new SpellInfo(
		                                                "Spiders Fang", "spi fan bit",
		                                                //SpellCircle.Fifth,
		                                                212,
		                                                9041,
		                                                CReagent.Kindling,
		                                                CReagent.Venom
		                                               );

        public override SpellCircle Circle
        {
            get { return SpellCircle.Fifth; }
        }

		public override double CastDelay{ get{ return 7.0; } }
		public override double RequiredSkill{ get{ return 30.0; } }
		public override int RequiredMana{ get{ return 10; } }

		public DarkElfSpidersFangSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}

		public override void OnCast()
		{
			if ( CheckSequence() )
			{
				if(this.Scroll!=null)
					Scroll.Consume();

				Item weap = new DarkElfSpidersFang( Caster );

				Caster.AddToBackpack( weap );
				Caster.SendMessage( "You summon a spiders fang and place it in your backpack." );

				Caster.PlaySound( 466 );

				Effects.SendLocationParticles( EffectItem.Create( Caster.Location, Caster.Map, EffectItem.DefaultDuration ), 0x376A, 1, 29, 1266, 2, 9962, 0 );
				Effects.SendLocationParticles( EffectItem.Create( new Point3D( Caster.X, Caster.Y, Caster.Z - 7 ), Caster.Map, EffectItem.DefaultDuration ), 0x37C4, 1, 29, 1266, 2, 9502, 0 );
			}
		}

		[FlipableAttribute( 0xF52, 0xF51 )]
		public class DarkElfSpidersFang : BaseKnife
		{
      private Mobile m_Owner;
			private DateTime m_Expire;
			private Timer m_Timer;
			
			public override WeaponAbility PrimaryAbility{ get{ return WeaponAbility.InfectiousStrike; } }
      public override WeaponAbility SecondaryAbility{ get{ return WeaponAbility.ShadowStrike; } }

      public override int AosStrengthReq{ get{ return 10; } }
      public override int AosMinDamage{ get{ return 20; } }
      public override int AosMaxDamage{ get{ return 25; } }
      public override int AosSpeed{ get{ return 80; } }

      public override int OldStrengthReq{ get{ return 1; } }
      public override int OldMinDamage{ get{ return 3; } }
      public override int OldMaxDamage{ get{ return 15; } }
      public override int OldSpeed{ get{ return 55; } }

      public override int InitMinHits{ get{ return 60; } }
      public override int InitMaxHits{ get{ return 80; } }

      public override SkillName DefSkill{ get{ return SkillName.Fencing; } }
      public override WeaponType DefType{ get{ return WeaponType.Piercing; } }
      public override WeaponAnimation DefAnimation{ get{ return WeaponAnimation.Pierce1H; } }

			[Constructable]
			public DarkElfSpidersFang( Mobile owner ) : base( 0xF52 )

			{
				WeaponAttributes.HitPoisonArea = 20;
				Weight = 2.0;
				Hue = 1150;
				Name = "Spiders Fang";
				
				double time = ( owner.Skills[SkillName.Poisoning].Value / 5.0 ) * VenomSpell.GetScalar( owner );
				m_Expire = DateTime.Now + TimeSpan.FromMinutes( (int)time );
				m_Timer = new InternalTimer( this, m_Expire );
				
				m_Timer.Start();
			}

			public override void GetDamageTypes( Mobile wielder, out int phys, out int fire, out int cold, out int pois, out int nrgy )
			{
				phys = 0; fire = 0; cold = 0; pois = 100;
				nrgy = 0;
			}

			public override bool CanEquip( Mobile m )
			{
				if ( m != m_Owner )
					return false;

				return true;
			}

			public void Remove()
			{
				m_Owner.SendMessage( "Your weapon's venom slowly dissipates." );
				Delete();
			}

			public DarkElfSpidersFang( Serial serial ) : base( serial )
			{
			}
			public override void AddNameProperties( ObjectPropertyList list )
			{
				base.AddNameProperties( list );

				list.Add( 1049644, "Temparary Spell Enchantment" );
			}

			public override void Serialize( GenericWriter writer )
			{
				base.Serialize( writer );

				writer.Write( (int) 0 ); // version
				writer.Write( m_Owner );
				writer.Write( m_Expire );
			}

			public override void Deserialize( GenericReader reader )
			{
				base.Deserialize( reader );

				int version = reader.ReadInt();
				m_Owner = reader.ReadMobile();
				m_Expire = reader.ReadDeltaTime();

				m_Timer = new InternalTimer( this, m_Expire );
				m_Timer.Start();
			}
		}

		private class InternalTimer : Timer
		{
			private DarkElfSpidersFang m_dagger;
			private DateTime m_Expire;

			public InternalTimer( DarkElfSpidersFang dagger, DateTime expire ) : base( TimeSpan.Zero, TimeSpan.FromSeconds( 0.1 ) )
			{
				m_dagger = dagger;
				m_Expire = expire;
			}

			protected override void OnTick()
			{
				if ( DateTime.Now >= m_Expire )
				{
					m_dagger.Remove();
					Stop();
				}
			}
		}
	}
}
